#
# spec file for package python-PyQRCode
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define modname PyQRCode
%{?sle15_python_module_pythons}
Name:           python-PyQRCode
Version:        1.3.6
Release:        6.3
Summary:        Python 3 module to generate QR Codes
License:        MIT
URL:            https://github.com/pyqrcode/pyqrcodeNG
# This is unofficial fork with some additional fixes, the canonical
# upstream repository is dead.
Source:         https://github.com/pyqrcode/pyqrcodeNG/archive/refs/tags/%{version}.tar.gz#/pyqrcodeNG-%{version}.tar.gz
# PATCH-FIX-UPSTREAM https://github.com/pyqrcode/pyqrcodeNG/pull/18
Patch0:         reproducible.patch
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pypng}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildRequires:  python3-Sphinx
BuildRequires:  python3-sphinx_rtd_theme
Provides:       python-PyQRCodeNG = %{version}-%{release}
Provides:       python-pyqrcodeng = %{version}-%{release}
Requires(post): update-alternatives
Requires(postun): update-alternatives
BuildArch:      noarch
%python_subpackages

%description
The PyQRCode module is a QR code generator that is simple to use and written in pure python.
The module can automates most of the building process for creating QR codes.
Most codes can be created using only two lines of code.

%package -n %{name}-doc
Summary:        Documentation files for %{name}

%description -n %{name}-doc
HTML Documentation for %{name}.

%prep
%autosetup -p1 -n pyqrcodeNG-%{version}

sed -i -e '1{\@^#!%{_bindir}/env python@d}' pyqrcodeng/{cli,qrspecial}.py

%build
%pyproject_wheel
sphinx-build -b html docs/ build/sphinx/html/
rm -rvf build/sphinx/html/{.buildinfo,.doctrees}

%install
%pyproject_install
%python_clone -a %{buildroot}%{_bindir}/pyqr
%python_expand %fdupes %{buildroot}/%{$python_sitelib}

%check
%pytest

%post
%python_install_alternative pyqr

%postun
%python_uninstall_alternative pyqr

%files %{python_files}
%license LICENSE
%doc README.rst CHANGES.rst
%python_alternative %{_bindir}/pyqr
%{python_sitelib}/PyQRCodeNG-%{version}*-info
%{python_sitelib}/pyqrcodeng

%files -n %{name}-doc
%doc build/sphinx/html

%changelog
* Wed Jan 22 2025 Steve Kowalik <steven.kowalik@suse.com>
- Explicitly BuildRequire sphinx_rtd_theme.
* Fri Dec  1 2023 Antonio Larrosa <alarrosa@suse.com>
- Add %%{?sle15_python_module_pythons}
* Thu May 11 2023 Ben Greiner <code@bnavigator.de>
- Replace build_sphinx setuptools hook with direct sphinx-build
  call -- fixes boo#1211051
* Wed Apr 20 2022 Matej Cepl <mcepl@suse.com>
- Clean up of the SPEC file.
* Wed Feb  2 2022 Bernhard Wiedemann <bwiedemann@suse.com>
- Add reproducible.patch to not include build date (boo#1047218)
* Thu Dec  9 2021 Matej Cepl <mcepl@suse.com>
- Update to 1.3.6:
  - Code improvements / refactorings
  - Optimized generation of numerical QR Codes
  - MUCH faster PNG writing (approx. twice as fast)
  - Don't raise a UnicodeError if the user provided binary data
    and sets the mode explicitly to 'binary'. Fixed by Mathieu
    <https://github.com/albatros69> (PR #13)
  - The builder raises more specific exceptions like
    VersionError, MaskError, DataOverflowError. This change is
    backwards compatible since all exceptions are inherited from
    ValueError.
  - Added "designator" property to QRCode. This encodes the
    version number and error correction level, i.e. "1-H"
  - Fixed alphanumeric encoding. The bug was introduced in the
    1.3.4 release
  - Added more test cases
  - Added CLI docs
  - (Deprecated) QRCode.terminal() did not work. Fixed.
  - Initial release of PyQRCode NG (PyQRCode Next Generation)
* Wed Dec  8 2021 pgajdos@suse.com
- do not require pytest-runner for build, it is not needed
* Thu May 14 2020 Antonio Larrosa <alarrosa@suse.com>
- Re-download source package which changed the topdir name
* Thu May 14 2020 Antonio Larrosa <alarrosa@suse.com>
- Do not build python2 version
* Mon Oct 14 2019 Matej Cepl <mcepl@suse.com>
- Replace %%fdupes -s with plain %%fdupes; hardlinks are better.
* Mon Apr  1 2019 Tomáš Chvátal <tchvatal@suse.com>
- Sort out with spec-cleaner
* Mon Mar 25 2019 Matej Cepl <mcepl@suse.com>
- Upgrade to 1.3.0 (from https://github.com/heuer/pyqrcode/):
  - Added support for meCards etc. contributed by Riccardo Metere
  - Skip detecting content type if constructor mode is given to
    constructor. Contributed by Martijn van Rheenen.
  - Moved tests from nose to pytest since nose is deprecated
  - Updated test environment: Added PyPy, PyPy3 and Python 3.6
  - QRCode.get_png_size() is deprecated, use
    QRCode.symbol_size(). The latter returns a (width, height)
    tuple, not an integer.
  - Deprecated QRCode.png_as_base64_str(), use
    QRCode.png_data_uri() which returns a valid URI instead of
    a Base64 encoded string
  - Faster PNG generation
  - Added CLI
  - Added term() method to QRCode which prints the QR Code to the
    terminal. This works with Windows and Unix.
  - Deprecated QRCode.terminal() in favor of QRCode.term()
  - Added "scale" parameter to QRCode.text
* Mon Mar 25 2019 Matěj Cepl <mcepl@suse.com>
- Initial packaging of the version 1.2.1
